@@ -1,7 +1,9 @@
 import os
+from typing import Dict
 
 from scimschema import core_schemas
 from scimschema._model import attribute
+from scimschema._model.model import Model
 from scimschema._model.schema_response import ScimResponse
 from scimschema.core_schemas import load_dict as _load_dict
 
@@ -15,7 +17,7 @@ def read_version() -> str:
 __version__ = read_version()
 
 
-def validate(data, extension_schema_definitions):
+def validate(data: Dict[str, Model], extension_schema_definitions: Dict[str, Model]):
     ScimResponse(
         data=data,
         core_schema_definitions=core_schemas.schema,
@@ -23,5 +25,5 @@ def validate(data, extension_schema_definitions):
     ).validate()
 
 
-def load_dict_to_schema(path):
+def load_dict_to_schema(path) -> Dict[str, Model]:
     return _load_dict(path=path)
